@@ -6,6 +6,9 @@ Confidential ML utilities.
 """
 
 
+from .constants import DataCategory  # noqa: F401
 from .logging import enable_confidential_logging  # noqa: F401
+from .exceptions import prefix_stack_trace  # noqa: F401
 
-__version__ = "0.6.2"
+
+__version__ = "0.7.0"
